# python-enhancements - Enhanced Python Classes

![Python package](https://github.com/manfred-kaiser/python-enhancements/workflows/Python%20package/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/enhancements/badge/?version=master)](https://enhancements.readthedocs.io/de/master/?badge=master)
[![CodeFactor](https://www.codefactor.io/repository/github/manfred-kaiser/python-enhancements/badge)](https://www.codefactor.io/repository/github/manfred-kaiser/python-enhancements)
[![Github version](https://img.shields.io/github/v/release/manfred-kaiser/python-enhancements?label=github&logo=github)](https://github.com/manfred-kaiser/python-enhancements/releases)
[![PyPI version](https://img.shields.io/pypi/v/enhancements.svg?logo=pypi&logoColor=FFE873)](https://pypi.org/project/enhancements/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/enhancements.svg?logo=python&logoColor=FFE873)](https://pypi.org/project/enhancements/)
[![PyPI downloads](https://pepy.tech/badge/enhancements/month)](https://pepy.tech/project/enhancements/month)
[![GitHub](https://img.shields.io/github/license/manfred-kaiser/python-enhancements.svg)](LICENSE)

`enhancements` is a python library which extends various python classes.
